# Flask-CKEditor

CKEditor integration for Flask, including image upload, code syntax highlighting, and more.


## Links

* [Documentation](https://flask-ckeditor.readthedocs.io/en/latest/)
* [PyPI](https://pypi.org/project/Flask-CKEditor/)
* [Examples](https://github.com/helloflask/flask-ckeditor/tree/master/examples)


## Donate

If you find Flask-CKEditor useful, please consider
[donating today](https://opencollective.com/flask-ckeditor/donate). Your donation keeps
Flask-CKEditor maintained and updated with CKEditor.


## License

This project is licensed under the MIT License (see the `LICENSE` file for details).
